﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Data;
using System.Windows.Threading;

namespace ValidateIndex
{
    public class MainWindowViewModel
    {
        private readonly MainWindow _mainWindow;
        private readonly RangeObservableCollection<RowModel> _items;
        private readonly ICollectionView _viewItems;
        private readonly DispatcherTimer _fillInDispatcherTimer;

        public MainWindowViewModel(MainWindow mainWindow)
        {
            _mainWindow = mainWindow;
            _items = new RangeObservableCollection<RowModel>();
            _viewItems = CollectionViewSource.GetDefaultView(_items);
            _fillInDispatcherTimer = new DispatcherTimer(
                TimeSpan.FromSeconds(3), DispatcherPriority.Normal, OnFillInTimer, _mainWindow.Dispatcher);
            _mainWindow.Loaded += OnMainWindowLoaded;
            _mainWindow.Closed += OnMainWindowClosed;
        }

        private void OnFillInTimer(object sender, EventArgs eventArgs)
        {
            FillItemsInWith5000NewItems();
        }

        public ICollectionView Items
        {
            get
            {
                return _viewItems;
            }
        }

        private void OnMainWindowLoaded(object sender, RoutedEventArgs routedEventArgs)
        {
            FillItemsInWith5000NewItems();
            _fillInDispatcherTimer.Start();
        }

        private readonly Random _random = new Random();

        private void FillItemsInWith5000NewItems()
        {
            var itemsList = new List<RowModel>();
            for (int index = 0; index < 5000; index++)
            {
                var item = new RowModel();
                item.Read = false;
                item.FormDescription = Guid.NewGuid().ToString();
                item.DateImport = DateTime.Now;
                item.DateSent = DateTime.Now;
                item.DateConfirm = DateTime.Now;
                item.DateLastAnswer = DateTime.Now;
                item.Year = DateTime.Now.Year.ToString();
                item.Period = DateTime.Now.DayOfWeek.ToString();
                item.ReсeiverCode = "002";
                item.Progress = "--*---";
                item.StateId = DocCirculationStates.InProgress;
                item.OrgName = Guid.NewGuid().ToString();
                item.OrganizationShortName = Guid.NewGuid().ToString();
                item.Owner = Guid.NewGuid().ToString();
                item.DocCircId = Guid.NewGuid().ToString();
                item.DocCircType = Convert.ToInt32(_random.NextDouble());
                item.TaxpayerId = Convert.ToInt32(_random.NextDouble());
                item.IdUser = Convert.ToInt32(_random.NextDouble());
                item.Layout = Convert.ToInt32(_random.NextDouble());
                item.TaxpayerInn = Convert.ToInt32(_random.NextDouble()).ToString();
                item.TaxpayerKpp = Convert.ToInt32(_random.NextDouble()).ToString();
                item.Name = Guid.NewGuid().ToString();
                item.FormCode = Convert.ToInt32(_random.NextDouble()).ToString();
                itemsList.Add(item);
            }
            _items.AddRange(itemsList);
        }

        private void OnMainWindowClosed(object sender, EventArgs eventArgs)
        {
            _fillInDispatcherTimer.Stop();
        }

    }
}
